@@ -1,5 +1,5 @@
 /*
-#  $Id: Driver_xst.h 15062 2012-01-02 15:16:55Z timbo $
+#  $Id: Driver_xst.h 15353 2012-07-13 12:31:30Z timbo $
 #  Copyright (c) 2002  Tim Bunce  Ireland
 #
 #  You may distribute under the terms of either the GNU General Public
@@ -28,7 +28,7 @@ dbixst_bounce_method(char *methname, int params)
     if (debug >= 3) {
 	PerlIO_printf(DBIc_LOGPIO(imp_xxh),
 	    "    -> %s (trampoline call with %d (%ld) params)\n", methname, params, (long)items);
-	xxx = xxx; /* avoid unused var warning */
+	PERL_UNUSED_VAR(xxx);
     }
     EXTEND(SP, params);
     PUSHMARK(SP);
@@ -69,7 +69,7 @@ dbdxst_bind_params(SV *sth, imp_sth_t *imp_sth, I32 items, I32 ax)
         }
 	sprintf(errmsg,"called with %d bind variables when %d are needed",
 		(int)items-1, DBIc_NUM_PARAMS(imp_sth));
-        DBIh_SET_ERR_CHAR(sth, imp_sth, "-1", -1, errmsg, Nullch, Nullch);
+        DBIh_SET_ERR_CHAR(sth, (imp_xxh_t*)imp_sth, "-1", -1, errmsg, Nullch, Nullch);
 	return 0;
     }
     idx = sv_2mortal(newSViv(0));
@@ -95,7 +95,7 @@ dbdxst_fetchall_arrayref(SV *sth, SV *slice, SV *batch_row_count)
     if (SvOK(slice)) {  /* should never get here */
 	char errmsg[99];
 	sprintf(errmsg,"slice param not supported by XS version of fetchall_arrayref");
-        DBIh_SET_ERR_CHAR(sth, imp_sth, "-1", -1, errmsg, Nullch, Nullch);
+        DBIh_SET_ERR_CHAR(sth, (imp_xxh_t*)imp_sth, "-1", -1, errmsg, Nullch, Nullch);
 	return &PL_sv_undef;
     }
     else {
